Sequences
:::::::::

.. toctree::
   :caption: Sequences
   :maxdepth: 2

   intro-Sequences.rst
   StringsandLists.rst
   IndexOperatorWorkingwiththeCharactersofaString.rst
   DisabmiguatingSquareBrackets.rst
   Length.rst
   TheSliceOperator.rst
   ConcatenationandRepetition.rst
   CountandIndex.rst
   SplitandJoin.rst
   Exercises.rst
   week2a1.rst
   